..
    This file is part of Inspire.
    Copyright (C) 2017 CERN.

    Inspire is free software; you can redistribute it
    and/or modify it under the terms of the GNU General Public License as
    published by the Free Software Foundation; either version 2 of the
    License, or (at your option) any later version.

    Inspire is distributed in the hope that it will be
    useful, but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with Inspire; if not, write to the
    Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
    MA 02111-1307, USA.

    In applying this license, CERN does not
    waive the privileges and immunities granted to it by virtue of its status
    as an Intergovernmental Organization or submit itself to any jurisdiction.

=====================
 inspire-json-merger
=====================

.. image:: https://img.shields.io/travis/inspirehep/inspire-json-merger.svg
        :target: https://travis-ci.org/inspirehep/inspire-json-merger

.. image:: https://img.shields.io/coveralls/inspirehep/inspire-json-merger.svg
        :target: https://coveralls.io/r/inspirehep/inspire-json-merger

.. image:: https://img.shields.io/github/tag/inspirehep/inspire-json-merger.svg
        :target: https://github.com/inspirehep/inspire-json-merger/releases

.. image:: https://img.shields.io/pypi/dm/inspire-json-merger.svg
        :target: https://pypi.python.org/pypi/inspire-json-merger

.. image:: https://img.shields.io/github/license/inspirehep/inspire-json-merger.svg
        :target: https://github.com/inspirehep/inspire-json-merger/blob/master/LICENSE

Project to set all the configurations necessary for the json-merger

*This is an experimental developer preview release.*

TODO: Please provide feature overview of module

Further documentation is available on
https://inspire-json-merger.readthedocs.io/
